'use strict';

exports.__esModule = true;

var _vue = require('vue');

var _vue2 = _interopRequireDefault(_vue);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * 企业应用管理SDK（API）
 */
exports.default = {

    /**
     * 取得企业订阅应用列表
     * 
     * @param {*} corporationId 企业编号 
     */
    getApplications: function getApplications(corporationId) {
        var params = { entId: corporationId };

        return _vue2.default.prototype.$fetch({
            url: '/corp/apps/list',
            method: 'GET',
            dataType: 'JSON',
            params: params
        });
    },


    /**
     * 取得企业可订阅应用列表
     * 
     * @param {*} corporationId 
     */
    getNoSubCorpApps: function getNoSubCorpApps(corporationId) {
        var params = { entId: corporationId };

        return _vue2.default.prototype.$fetch({
            url: '/corp/apps/nosetlist',
            method: 'GET',
            dataType: 'JSON',
            params: params
        });
    },


    /**
     * 取得我的应用订阅应用列表
     * 
     * @param {*} corporationId 
     */
    getCorpCustApps: function getCorpCustApps(corporationId) {
        var params = { entId: corporationId };

        return _vue2.default.prototype.$fetch({
            url: '/corp/custApps/list',
            method: 'GET',
            dataType: 'JSON',
            params: params
        });
    },


    /**
     * 订阅应用
     * 
     * @param {*} corporationId 
     * @param {*} appId 
     */
    subscribe: function subscribe(corporationId, appId) {
        var params = { entId: corporationId, appId: appId };

        return _vue2.default.prototype.$fetch({
            url: '/corp/app/subscribe',
            method: 'GET',
            dataType: 'JSON',
            params: params
        });
    },


    /**
     * 退订应用
     * 
     * @param {*} corporationId 
     * @param {*} appId 
     */
    unsubscribe: function unsubscribe(corporationId, appId) {
        var params = { entId: corporationId, appId: appId };

        return _vue2.default.prototype.$fetch({
            url: '/corp/app/unsubscribe',
            method: 'GET',
            dataType: 'JSON',
            params: params
        });
    }
};