'use strict';

exports.__esModule = true;

var _vue = require('vue');

var _vue2 = _interopRequireDefault(_vue);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * 企业信息管理SDK（API）
 */
exports.default = {

    /**
     * 企业初始化，包括企业、组织机构根节点、管理员和默认系统管理权限
     * 
     * @param {*} data 
     */
    initializeCorporation: function initializeCorporation(data) {
        return _vue2.default.prototype.$fetch({
            url: '/corp/initialize',
            method: 'POST',
            dataType: 'JSON',
            data: data
        });
    },


    /**
     * 注册企业信息
     * 
     * @param {*} data 
     */
    registeCorporation: function registeCorporation(data) {
        return _vue2.default.prototype.$fetch({
            url: '/corp/create',
            method: 'POST',
            dataType: 'JSON',
            data: data
        });
    },


    /**
     * 更新企业信息
     * 
     * @param {*} data 
     */
    updateCorporation: function updateCorporation(data) {
        return _vue2.default.prototype.$fetch({
            url: '/corp/update',
            method: 'POST',
            dataType: 'JSON',
            data: data
        });
    },


    /**
     * 查询企业信息
     */
    getCorporationInfo: function getCorporationInfo(corporationId) {
        var params = { corpid: corporationId };

        return _vue2.default.prototype.$fetch({
            url: '/corp/get',
            method: 'GET',
            dataType: 'JSON',
            params: params
        });
    },


    /**
     * 取得用户所管理的企业号列表
     * 
     * @param {*} userid 
     */
    getCorpByManage: function getCorpByManage(userid) {
        var params = { userid: userid };

        return _vue2.default.prototype.$fetch({
            url: '/corp/managelist',
            method: 'GET',
            dataType: 'JSON',
            params: params
        });
    },


    /**
     * 取得企业号管理者列表
     * 
     * @param {*} corporationId 
     */
    getCorpManages: function getCorpManages(corporationId) {
        var params = { entId: corporationId };

        return _vue2.default.prototype.$fetch({
            url: '/corp/manager/list',
            method: 'GET',
            dataType: 'JSON',
            params: params
        });
    }
};