'use strict';

exports.__esModule = true;

var _vue = require('vue');

var _vue2 = _interopRequireDefault(_vue);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = {

    // =========================================
    //  取得企业号组织机构信息
    // =========================================
    getOrgTree: function getOrgTree(entId) {
        return _vue2.default.prototype.$fetch({
            url: '/org/tree/' + entId,
            method: 'GET',
            dataType: 'JSON'
        });
    },


    // =========================================
    //  取得企业号指定组织机构信息
    // =========================================
    getOrgTreeByOrgId: function getOrgTreeByOrgId(entId, orgId) {
        return _vue2.default.prototype.$fetch({
            url: '/org/tree/' + entId + '/' + orgId,
            method: 'GET',
            dataType: 'JSON'
        });
    },


    // =========================================
    //  查询企业号指定组织机构信息
    // =========================================
    searchOrgTree: function searchOrgTree(entId, filterText, hasUsers) {
        var params = {
            entId: entId,
            filterText: filterText,
            hasUsers: hasUsers
        };
        return _vue2.default.prototype.$fetch({
            url: '/org/tree/search',
            method: 'GET',
            dataType: 'JSON',
            params: params
        });
    },


    // =========================================
    //  取得企业号组织机构信息(带用户信息)
    // =========================================
    getOrgTreeHasUsers: function getOrgTreeHasUsers(entId) {
        return _vue2.default.prototype.$fetch({
            url: '/org/tree/hasUsers/' + entId,
            method: 'GET',
            dataType: 'JSON'
        });
    },


    // =========================================
    //  取得企业号指定组织机构的子组织信息（带用户信息）
    // =========================================
    getChildOrgHasUsers: function getChildOrgHasUsers(entId, parentOrgId) {
        return _vue2.default.prototype.$fetch({
            url: '/org/child/hasUsers/' + entId + '/' + parentOrgId,
            method: 'GET',
            dataType: 'JSON'
        });
    },


    // =========================================
    //  取得企业号组织机构信息(不带用户信息)
    // =========================================
    getOrgTreeNoUsers: function getOrgTreeNoUsers(entId) {
        return _vue2.default.prototype.$fetch({
            url: '/org/tree/noUsers/' + entId,
            method: 'GET',
            dataType: 'JSON'
        });
    },


    // =========================================
    //  取得企业号指定组织机构的子组织信息（不带用户信息）
    // =========================================
    getChildOrgNoUsers: function getChildOrgNoUsers(entId, parentOrgId) {
        return _vue2.default.prototype.$fetch({
            url: '/org/child/noUsers/' + entId + '/' + parentOrgId,
            method: 'GET',
            dataType: 'JSON'
        });
    },


    // =========================================
    //  取得企业号组织机构信息
    // =========================================
    getOrgSelectTreeData: function getOrgSelectTreeData(entId, orgId) {
        var params = { org: '' };
        if (orgId) {
            params = { org: orgId };
        }
        return _vue2.default.prototype.$fetch({
            url: '/org/selecttree/' + entId,
            method: 'GET',
            dataType: 'JSON',
            params: params
        });
    },


    // =========================================
    //  取得企业的下级单位
    // =========================================
    getChildOrg: function getChildOrg(entId, orgId) {

        return _vue2.default.prototype.$fetch({
            url: '/org/child/' + entId + '/' + orgId,
            method: 'GET',
            dataType: 'JSON'
        });
    },


    // =========================================
    //  取得企业号组织下用户信息
    // =========================================
    getOrgUserById: function getOrgUserById(entId, orgId, page) {

        return _vue2.default.prototype.$fetch({
            url: '/org/users/id/' + entId + '/' + orgId,
            method: 'GET',
            dataType: 'JSON',
            params: { page: JSON.stringify(page) }
        });
    },


    // =========================================
    //  取得企业下所有用户信息
    // =========================================
    getEntUserById: function getEntUserById(entId, page) {

        return _vue2.default.prototype.$fetch({
            url: '/org/users/list/' + entId,
            method: 'GET',
            dataType: 'JSON',
            params: { page: JSON.stringify(page) }
        });
    },


    // =========================================
    //  根据查询条件取得企业号组织下用户信息
    // =========================================
    getOrgListByParams: function getOrgListByParams(data) {

        return _vue2.default.prototype.$fetch({
            url: 'org/getlistByParams',
            method: 'POST',
            dataType: 'JSON',
            params: { filter: JSON.stringify(data) }
        });
    },


    // =========================================
    //  取得企业号组织下用户信息
    // =========================================
    getOrgUserByCode: function getOrgUserByCode(entId, orgCode, params) {

        return _vue2.default.prototype.$fetch({
            url: '/org/users/code/' + entId + '/' + orgCode,
            method: 'GET',
            dataType: 'JSON',
            params: params
        });
    },


    // =========================================
    //  添加组织
    // =========================================
    addOrg: function addOrg(data) {

        return _vue2.default.prototype.$fetch({
            url: '/org/add',
            method: 'POST',
            dataType: 'JSON',
            data: data
        });
    },


    // =========================================
    //  更新组织信息
    // =========================================
    updateOrg: function updateOrg(data) {

        return _vue2.default.prototype.$fetch({
            url: '/org/update',
            method: 'POST',
            dataType: 'JSON',
            data: data
        });
    },


    // =========================================
    //  移动组织信息
    // =========================================
    moveOrg: function moveOrg(entId, sourceOrg, targetOrg, position) {

        var data = {
            entId: entId,
            source: sourceOrg,
            target: targetOrg,
            position: position
        };

        return _vue2.default.prototype.$fetch({
            url: '/org/move',
            method: 'POST',
            dataType: 'JSON',
            data: data
        });
    },


    // =========================================
    //  删除组织
    // =========================================
    deleteOrg: function deleteOrg(entId, orgId) {

        return _vue2.default.prototype.$fetch({
            url: '/org/delete/' + entId + '/' + orgId,
            method: 'GET',
            dataType: 'JSON'
        });
    },


    // =========================================
    //  启用组织
    // =========================================
    enableOrg: function enableOrg(entId, orgId) {

        return _vue2.default.prototype.$fetch({
            url: '/org/enable/' + entId + '/' + orgId,
            method: 'GET',
            dataType: 'JSON'
        });
    },


    // =========================================
    //  禁用组织
    // =========================================
    disableOrg: function disableOrg(entId, orgId) {

        return _vue2.default.prototype.$fetch({
            url: '/org/disable/' + entId + '/' + orgId,
            method: 'GET',
            dataType: 'JSON'
        });
    },


    // =========================================
    //  向组织添加新用户
    // =========================================
    addOrgUser: function addOrgUser(data) {

        return _vue2.default.prototype.$fetch({
            url: '/org/user/add',
            method: 'POST',
            dataType: 'JSON',
            data: data
        });
    },


    // =========================================
    //  更新用户信息
    // =========================================
    updateOrgUser: function updateOrgUser(data) {

        return _vue2.default.prototype.$fetch({
            url: '/org/user/update',
            method: 'POST',
            dataType: 'JSON',
            data: data
        });
    },


    // =========================================
    //  更新用户密码
    // =========================================
    updateOrgUserPassWord: function updateOrgUserPassWord(data) {

        return _vue2.default.prototype.$fetch({
            url: '/org/user/updatePassWord',
            method: 'POST',
            dataType: 'JSON',
            data: data
        });
    },


    // =========================================
    //  删除用户从组织中
    // =========================================
    deleteOrgUser: function deleteOrgUser(entId, userId) {

        return _vue2.default.prototype.$fetch({
            url: '/org/user/delete/' + entId + '/' + userId,
            method: 'GET',
            dataType: 'JSON'
        });
    },


    // =========================================
    //  通过组织名称查询企业下的组织
    // =========================================
    getOrgByName: function getOrgByName(entId, orgName) {

        return _vue2.default.prototype.$fetch({
            url: 'org/name/' + entId + '/' + orgName,
            method: 'GET',
            dataType: 'JSON'
        });
    },


    // =========================================
    //  通过用户姓名查询企业下的用户
    // =========================================
    getOrgUserByName: function getOrgUserByName(entId, userName) {

        return _vue2.default.prototype.$fetch({
            url: 'org/users/name/' + entId + '/' + userName,
            method: 'GET',
            dataType: 'JSON'
        });
    },


    // =========================================
    //  取得企业下所有的组织
    // =========================================
    getAllOrg: function getAllOrg(entId) {

        return _vue2.default.prototype.$fetch({
            url: 'org/' + entId,
            method: 'GET',
            dataType: 'JSON'
        });
    },


    // =========================================
    //  增加核算人员
    // =========================================
    addUser: function addUser(data) {

        return _vue2.default.prototype.$fetch({
            url: 'org/user/adduser',
            method: 'POST',
            dataType: 'JSON',
            // params: {filter: JSON.stringify(data)}
            data: data
        });
    },


    // =========================================
    //  设置核算负责人
    // =========================================
    setHeader: function setHeader(ids, headerId) {
        return _vue2.default.prototype.$fetch({
            url: 'org/user/header/' + ids + '/' + headerId,
            method: 'GET',
            dataType: 'JSON'
        });
    },


    // =========================================
    //  核算负责人注册
    // =========================================
    regist: function regist(data) {
        return _vue2.default.prototype.$fetch({
            url: 'org/user/regist',
            method: 'POST',
            dataType: 'JSON',
            data: data
        });
    },


    // =========================================
    //  更改用户部门信息
    // =========================================
    changeUserOrg: function changeUserOrg(data) {
        return _vue2.default.prototype.$fetch({
            url: '/user/org/change',
            method: 'POST',
            dataType: 'JSON',
            data: data
        });
    },


    // =========================================
    //  取得企业号指定组织机构信息
    // =========================================
    getOrgInfo: function getOrgInfo(entId, orgId) {
        return _vue2.default.prototype.$fetch({
            url: '/org/get/' + entId + '/' + orgId,
            method: 'GET',
            dataType: 'JSON'
        });
    }
};