'use strict';

exports.__esModule = true;

var _vue = require('vue');

var _vue2 = _interopRequireDefault(_vue);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * 标签管理SDK（API）
 */
exports.default = {

    /**
     * 添加标签
     * 
     * @param {*} data 
     */
    add: function add(data) {

        return _vue2.default.prototype.$fetch({
            url: 'tag/create',
            method: 'POST',
            dataType: 'JSON',
            data: data
        });
    },


    /**
     * 更新标签
     * 
     * @param {*} data 
     */
    update: function update(data) {

        return _vue2.default.prototype.$fetch({
            url: 'tag/update',
            method: 'POST',
            dataType: 'JSON',
            data: data
        });
    },


    /**
     * 删除标签
     * 
     * @param {*}} corp 
     * @param {*} id 
     */
    delete: function _delete(corp, id) {

        return _vue2.default.prototype.$fetch({
            url: 'tag/delete/' + corp + '/' + id,
            method: 'GET',
            dataType: 'JSON'
        });
    },


    /**
     * 获取企业标签(树形结构)
     * 
     * @param {*} corp 
     * @param {*} type 
     */
    getTree: function getTree(corp, type) {

        return _vue2.default.prototype.$fetch({
            url: 'tag/list/' + corp + '/' + type,
            method: 'GET',
            dataType: 'JSON'
        });
    },


    /**
     * 获取企业标签列表
     * 
     * @param {*} corp 
     * @param {*} type 
     */
    getList: function getList(corp, type) {

        return _vue2.default.prototype.$fetch({
            url: 'tag/taglist/' + corp + '/' + type,
            method: 'GET',
            dataType: 'JSON'
        });
    },


    /**
     * 根据TAG_TYPE获取所有的数据 返回列表是树形结构的
     * 
     * @param {*} params 
     */
    getByParam: function getByParam(params) {
        var corp = params.corp;
        var type = params.type;

        return _vue2.default.prototype.$fetch({
            url: 'tag/list/' + corp + '/' + type,
            method: 'GET',
            dataType: 'JSON'
        });
    },


    /**
     * 通过名称获取企业标签
     * 
     * @param {*} corp 
     * @param {*} tagName 
     */
    getByName: function getByName(corp, tagName) {

        return _vue2.default.prototype.$fetch({
            url: 'tag/list/' + corp + '/' + tagName,
            method: 'GET',
            dataType: 'JSON'
        });
    },


    /**
     * 通过父节点获取所有标签
     * 
     * @param {*} params 
     */
    getChild: function getChild(params) {
        var corp = params.corp;
        var parentCode = params.parentCode;
        return _vue2.default.prototype.$fetch({
            url: 'tag/child/' + corp + '/' + parentCode,
            method: 'GET',
            dataType: 'JSON'
        });
    },


    /**
     * 根据TAG_TYPE获取所有的数据
     * 
     * @param {*} params 
     */
    getByType: function getByType(params) {
        var corp = params.corp;
        var type = params.type;
        return _vue2.default.prototype.$fetch({
            url: 'tag/all/' + corp + '/' + type,
            method: 'GET',
            dataType: 'JSON'
        });
    }
};