'use strict';

exports.__esModule = true;

var _vue = require('vue');

var _vue2 = _interopRequireDefault(_vue);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = {
    /**
     * 上传附件
     *
     * @param {string} url  文件上传URL
     * @param {JSON} data  文件信息
     * @param {JSON} param 数据参数
     */
    uploadAttachment: function uploadAttachment(url, data, param) {
        var fd = new FormData();
        fd.append('file', data.file);
        fd.append('GID', param.GID);
        fd.append('businessType', param.businessType);
        fd.append('businessId', param.businessId);
        return _vue2.default.prototype.$fetch({
            url: url,
            method: 'POST',
            headers: {
                'content-type': 'multipart/form-data',
                'access-token': param.token,
                account: param.userId,
                'account-name': param.userName
            },
            data: fd
        });
    },


    /**
     * 下载文件
     *
     * @param {*} data
     */
    downloadAttachment: function downloadAttachment(data) {
        return _vue2.default.prototype.$fetch({
            url: 'attachment/download',
            method: 'POST',
            dataType: 'JSON',
            data: data,
            responseType: 'blob'
        });
    },


    /**
     * 移除文件
     * @param gid     组id
     * @param fileId  文件id
     */
    removeAttachment: function removeAttachment(gid, fileId) {
        var params = {
            GID: gid,
            fileId: fileId
        };
        return _vue2.default.prototype.$fetch({
            url: 'attachment/remove',
            method: 'GET',
            dataType: 'JSON',
            params: params
        });
    },


    /**
     * 获取文件列表
     * @param gid
     * @param clearFlg
     */
    attachmentList: function attachmentList(gid, clearFlg) {
        var params = {
            groupId: gid,
            clearFlg: clearFlg
        };
        return _vue2.default.prototype.$fetch({
            url: 'attachment/list',
            method: 'GET',
            dataType: 'JSON',
            params: params
        });
    }
};