'use strict';

exports.__esModule = true;

var _vue = require('vue');

var _vue2 = _interopRequireDefault(_vue);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = {

    /**
     * 注册用户
     * @param {User} data 用户信息 
     */
    registeUser: function registeUser(data) {
        return _vue2.default.prototype.$fetch({
            url: '/user/create',
            method: 'POST',
            dataType: 'JSON',
            data: data
        });
    },


    /**
     * 更新用户信息,不更新密码
     * 
     * @param {*} data 用户信息
     */
    update: function update(data) {
        return _vue2.default.prototype.$fetch({
            url: '/user/update',
            method: 'POST',
            dataType: 'JSON',
            data: data
        });
    },


    /**
     * 更新用户密码
     * 
     * @param {用户编号}} userId 
     * @param {原密码} password 
     * @param {新密码} newPassword 
     */
    updatePwd: function updatePwd(userId, password, newPassword) {
        var params = {
            userId: userId,
            password: password,
            newPassword: newPassword
        };

        return _vue2.default.prototype.$fetch({
            url: '/user/updatePwd',
            method: 'GET',
            dataType: 'JSON',
            params: params
        });
    },


    /**
     * 获取用户信息
     * 
     * @param {String} userId 
     */
    getUserInfo: function getUserInfo(userId) {
        var params = { userid: userId };
        return _vue2.default.prototype.$fetch({
            url: '/user/get',
            method: 'GET',
            dataType: 'JSON',
            params: params
        });
    },


    /**
     * 用户订阅应用
     * 
     * @param {Application} data 
     */
    subscriptUserApp: function subscriptUserApp(data) {
        return _vue2.default.prototype.$fetch({
            url: '/userapp/create',
            method: 'POST',
            dataType: 'JSON',
            data: data
        });
    },


    /**
     * 用户取消订阅
     * 
     * @param {*} userId 用户编号
     * @param {*} appId 应用编号
     */
    unsubscriptUserApp: function unsubscriptUserApp(userId, appId) {

        var params = {
            userid: userId,
            appid: appId
        };

        return _vue2.default.prototype.$fetch({
            url: '/userapp/remove',
            method: 'GET',
            dataType: 'JSON',
            params: params
        });
    },


    /**
     * 获取用户应用列表
     * 
     * @param {string} userId  用户编号
     */
    getUserApps: function getUserApps(userId) {
        return _vue2.default.prototype.$fetch({
            url: '/userapp/list',
            method: 'GET',
            dataType: 'JSON',
            params: { userid: userId }
        });
    },


    /**
     * 获取路由
     * 
     * @param {string} entId 企业编号
     * @param {string} userId 用户编号
     */
    fetchRouter: function fetchRouter(entId, userId) {
        var params = {
            entId: entId,
            userid: userId
        };

        return _vue2.default.prototype.$fetch({
            url: '/userapp/routes',
            method: 'GET',
            dataType: 'JSON',
            params: params
        });
    },


    /**
     * 获取用户企业用户列表
     * 
     * @param {*} data 
     */
    getEntUserList: function getEntUserList(data) {
        return _vue2.default.prototype.$fetch({
            url: '/user/list',
            method: 'POST',
            dataType: 'JSON',
            params: { filter: JSON.stringify(data) }
        });
    }
};