import Vue from 'vue'

/**
 * 企业应用管理SDK（API）
 */
export default {

    /**
     * 取得企业订阅应用列表
     * 
     * @param {*} corporationId 企业编号 
     */
    getApplications(corporationId) {
        let params = {entId:corporationId}

        return Vue.prototype.$fetch({
            url: '/corp/apps/list',
            method: 'GET',
            dataType: 'JSON',
            params: params
        })

    },

    /**
     * 取得企业可订阅应用列表
     * 
     * @param {*} corporationId 
     */
    getNoSubCorpApps(corporationId) {
        let params = {entId:corporationId}

        return Vue.prototype.$fetch({
            url: '/corp/apps/nosetlist',
            method: 'GET',
            dataType: 'JSON',
            params: params
        })
    },

    /**
     * 取得我的应用订阅应用列表
     * 
     * @param {*} corporationId 
     */
    getCorpCustApps(corporationId) {
        let params = {entId:corporationId}

        return Vue.prototype.$fetch({
            url: '/corp/custApps/list',
            method: 'GET',
            dataType: 'JSON',
            params: params
        })
    },

    /**
     * 订阅应用
     * 
     * @param {*} corporationId 
     * @param {*} appId 
     */
    subscribe(corporationId,appId) {
        let params = {entId:corporationId,appId:appId}

        return Vue.prototype.$fetch({
            url: '/corp/app/subscribe',
            method: 'GET',
            dataType: 'JSON',
            params: params
        })
    },

    /**
     * 退订应用
     * 
     * @param {*} corporationId 
     * @param {*} appId 
     */
    unsubscribe(corporationId,appId) {
        let params = {entId:corporationId,appId:appId}

        return Vue.prototype.$fetch({
            url: '/corp/app/unsubscribe',
            method: 'GET',
            dataType: 'JSON',
            params: params
        })
    }
}