import Vue from 'vue'

/**
 * 企业信息管理SDK（API）
 */
export default {

    /**
     * 企业初始化，包括企业、组织机构根节点、管理员和默认系统管理权限
     * 
     * @param {*} data 
     */
     initializeCorporation(data) {
        return Vue.prototype.$fetch({
            url: '/corp/initialize',
            method: 'POST',
            dataType:'JSON',
            data
        })
    },

    /**
     * 注册企业信息
     * 
     * @param {*} data 
     */
    registeCorporation(data) {
        return Vue.prototype.$fetch({
            url: '/corp/create',
            method: 'POST',
            dataType:'JSON',
            data
        })
    },

    /**
     * 更新企业信息
     * 
     * @param {*} data 
     */
    updateCorporation(data) {
        return Vue.prototype.$fetch({
            url: '/corp/update',
            method: 'POST',
            dataType:'JSON',
            data
        })
    },

    /**
     * 查询企业信息
     */
    getCorporationInfo(corporationId) {
        var params = {corpid:corporationId}

        return Vue.prototype.$fetch({
            url: '/corp/get',
            method: 'GET',
            dataType:'JSON',
            params:params
        })
    },

    /**
     * 取得用户所管理的企业号列表
     * 
     * @param {*} userid 
     */
    getCorpByManage(userid) {
        let params = {userid:userid}
    
        return Vue.prototype.$fetch({
            url: '/corp/managelist',
            method: 'GET',
            dataType: 'JSON',
            params: params
        })
    },

    /**
     * 取得企业号管理者列表
     * 
     * @param {*} corporationId 
     */
    getCorpManages(corporationId) {
        let params = {entId:corporationId}
    
        return Vue.prototype.$fetch({
            url: '/corp/manager/list',
            method: 'GET',
            dataType: 'JSON',
            params: params
        })
    }
    
}