import Vue from 'vue'

export default {

    // =========================================
    //  取得企业号组织机构信息
    // =========================================
    getOrgTree(entId) {
        return Vue.prototype.$fetch({
            url: '/org/tree/' + entId,
            method: 'GET',
            dataType: 'JSON'
        })
    },

    // =========================================
    //  取得企业号指定组织机构信息
    // =========================================
    getOrgTreeByOrgId(entId,orgId) {
        return Vue.prototype.$fetch({
            url: '/org/tree/' + entId + '/' + orgId,
            method: 'GET',
            dataType: 'JSON'
        })
    },

    // =========================================
    //  查询企业号指定组织机构信息
    // =========================================
    searchOrgTree(entId, filterText, hasUsers) {
        let params = {
            entId: entId,
            filterText: filterText,
            hasUsers: hasUsers
        }
        return Vue.prototype.$fetch({
            url: '/org/tree/search',
            method: 'GET',
            dataType: 'JSON',
            params: params
        })
    },

    // =========================================
    //  取得企业号组织机构信息(带用户信息)
    // =========================================
    getOrgTreeHasUsers(entId) {
        return Vue.prototype.$fetch({
            url: '/org/tree/hasUsers/' + entId,
            method: 'GET',
            dataType: 'JSON'
        })
    },

    // =========================================
    //  取得企业号指定组织机构的子组织信息（带用户信息）
    // =========================================
    getChildOrgHasUsers(entId,parentOrgId) {
        return Vue.prototype.$fetch({
            url: '/org/child/hasUsers/' + entId + '/' + parentOrgId,
            method: 'GET',
            dataType: 'JSON'
        })
    },

        // =========================================
    //  取得企业号组织机构信息(不带用户信息)
    // =========================================
    getOrgTreeNoUsers(entId) {
        return Vue.prototype.$fetch({
            url: '/org/tree/noUsers/' + entId,
            method: 'GET',
            dataType: 'JSON'
        })
    },

    // =========================================
    //  取得企业号指定组织机构的子组织信息（不带用户信息）
    // =========================================
    getChildOrgNoUsers(entId,parentOrgId) {
        return Vue.prototype.$fetch({
            url: '/org/child/noUsers/' + entId + '/' + parentOrgId,
            method: 'GET',
            dataType: 'JSON'
        })
    },

    // =========================================
    //  取得企业号组织机构信息
    // =========================================
    getOrgSelectTreeData(entId,orgId) {
        var params = {org: ''}
        if(orgId){
            params = {org: orgId}
        }
        return Vue.prototype.$fetch({
            url: '/org/selecttree/' + entId,
            method: 'GET',
            dataType: 'JSON',
            params: params
        })
    },

    // =========================================
    //  取得企业的下级单位
    // =========================================
    getChildOrg(entId,orgId) {

        return Vue.prototype.$fetch({
            url: '/org/child/' + entId + '/' + orgId,
            method: 'GET',
            dataType: 'JSON'
        })

    },

    // =========================================
    //  取得企业号组织下用户信息
    // =========================================
    getOrgUserById(entId,orgId,page) {

        return Vue.prototype.$fetch({
            url: '/org/users/id/' + entId + '/' + orgId,
            method: 'GET',
            dataType: 'JSON',
            params: {page:JSON.stringify(page)}
        })

    },
    
    // =========================================
    //  取得企业下所有用户信息
    // =========================================
    getEntUserById(entId,page) {

        return Vue.prototype.$fetch({
            url: '/org/users/list/' + entId,
            method: 'GET',
            dataType: 'JSON',
            params: {page:JSON.stringify(page)}
        })

    },

    // =========================================
    //  根据查询条件取得企业号组织下用户信息
    // =========================================
    getOrgListByParams (data) {

        return Vue.prototype.$fetch({
            url: 'org/getlistByParams',
            method: 'POST',
            dataType:'JSON',
            params: {filter:JSON.stringify(data)}
        })

    },

    // =========================================
    //  取得企业号组织下用户信息
    // =========================================
    getOrgUserByCode(entId,orgCode,params) {

        return Vue.prototype.$fetch({
            url: '/org/users/code/' + entId + '/' + orgCode,
            method: 'GET',
            dataType: 'JSON',
            params: params
        })

    },

    // =========================================
    //  添加组织
    // =========================================
    addOrg(data) {

        return Vue.prototype.$fetch({
            url: '/org/add',
            method: 'POST',
            dataType: 'JSON',
            data
        })

    },

    // =========================================
    //  更新组织信息
    // =========================================
    updateOrg(data) {

        return Vue.prototype.$fetch({
            url: '/org/update',
            method: 'POST',
            dataType: 'JSON',
            data
        })

    },

    // =========================================
    //  移动组织信息
    // =========================================
    moveOrg(entId,sourceOrg,targetOrg,position) {
        
        let data = {
            entId:entId,
            source: sourceOrg,
            target: targetOrg,
            position: position
        }

        return Vue.prototype.$fetch({
            url: '/org/move',
            method: 'POST',
            dataType: 'JSON',
            data
        })

    },

    // =========================================
    //  删除组织
    // =========================================
    deleteOrg(entId,orgId) {

        return Vue.prototype.$fetch({
            url: '/org/delete/'+entId + '/' + orgId,
            method: 'GET',
            dataType: 'JSON'
        })

    },

    // =========================================
    //  启用组织
    // =========================================
    enableOrg(entId,orgId) {

        return Vue.prototype.$fetch({
            url: '/org/enable/'+entId + '/' + orgId,
            method: 'GET',
            dataType: 'JSON'
        })

    },

    // =========================================
    //  禁用组织
    // =========================================
    disableOrg(entId,orgId) {

        return Vue.prototype.$fetch({
            url: '/org/disable/'+entId + '/' + orgId,
            method: 'GET',
            dataType: 'JSON'
        })

    },

    // =========================================
    //  向组织添加新用户
    // =========================================
    addOrgUser(data) {

        return Vue.prototype.$fetch({
            url: '/org/user/add',
            method: 'POST',
            dataType: 'JSON',
            data
        })

    },

    // =========================================
    //  更新用户信息
    // =========================================
    updateOrgUser(data) {

        return Vue.prototype.$fetch({
            url: '/org/user/update',
            method: 'POST',
            dataType: 'JSON',
            data
        })

    },

    // =========================================
    //  更新用户密码
    // =========================================
    updateOrgUserPassWord(data) {

        return Vue.prototype.$fetch({
            url: '/org/user/updatePassWord',
            method: 'POST',
            dataType: 'JSON',
            data
        })

    },

    // =========================================
    //  删除用户从组织中
    // =========================================
    deleteOrgUser(entId,userId) {

        return Vue.prototype.$fetch({
            url: '/org/user/delete/'+entId + '/' + userId,
            method: 'GET',
            dataType: 'JSON'
        })

    },

    // =========================================
    //  通过组织名称查询企业下的组织
    // =========================================
    getOrgByName(entId,orgName) {

        return Vue.prototype.$fetch({
            url: 'org/name/'+entId + '/' + orgName,
            method: 'GET',
            dataType: 'JSON'
        })

    },


    // =========================================
    //  通过用户姓名查询企业下的用户
    // =========================================
    getOrgUserByName(entId,userName) {

        return Vue.prototype.$fetch({
            url: 'org/users/name/'+entId + '/' + userName,
            method: 'GET',
            dataType: 'JSON'
        })

    },

    // =========================================
    //  取得企业下所有的组织
    // =========================================
    getAllOrg(entId) {

        return Vue.prototype.$fetch({
            url: 'org/' + entId,
            method: 'GET',
            dataType: 'JSON'
        })

    },

    // =========================================
    //  增加核算人员
    // =========================================
    addUser(data) {

        return Vue.prototype.$fetch({
            url: 'org/user/adduser',
            method: 'POST',
            dataType: 'JSON',
            // params: {filter: JSON.stringify(data)}
            data
        })

    },

    // =========================================
    //  设置核算负责人
    // =========================================
    setHeader(ids, headerId) {
        return Vue.prototype.$fetch({
            url: 'org/user/header/' + ids + '/' + headerId,
            method: 'GET',
            dataType: 'JSON',
        })
    },

    // =========================================
    //  核算负责人注册
    // =========================================
    regist(data) {
        return Vue.prototype.$fetch({
            url: 'org/user/regist',
            method: 'POST',
            dataType: 'JSON',
            data
        })
    },

    // =========================================
    //  更改用户部门信息
    // =========================================
     changeUserOrg(data) {
        return Vue.prototype.$fetch({
            url: '/user/org/change',
            method: 'POST',
            dataType:'JSON',
            data
        })
    },

    // =========================================
    //  取得企业号指定组织机构信息
    // =========================================
    getOrgInfo(entId,orgId) {
        return Vue.prototype.$fetch({
            url: '/org/get/' + entId + '/' + orgId,
            method: 'GET',
            dataType: 'JSON'
        })
    },
}