import Vue from 'vue'

/**
 * 标签管理SDK（API）
 */
export default {
    
    /**
     * 添加标签
     * 
     * @param {*} data 
     */
    add(data) {

        return Vue.prototype.$fetch({
            url: 'tag/create',
            method: 'POST',
            dataType:'JSON',
            data
        })
    
    },

    /**
     * 更新标签
     * 
     * @param {*} data 
     */
    update(data) {

        return Vue.prototype.$fetch({
            url: 'tag/update',
            method: 'POST',
            dataType:'JSON',
            data
        })
    
    },

    /**
     * 删除标签
     * 
     * @param {*}} corp 
     * @param {*} id 
     */
    delete(corp,id) {

        return Vue.prototype.$fetch({
            url: 'tag/delete/'+ corp +'/'+ id,
            method: 'GET',
            dataType:'JSON'
        })
    
    },

    /**
     * 获取企业标签(树形结构)
     * 
     * @param {*} corp 
     * @param {*} type 
     */
    getTree(corp,type) {

        return Vue.prototype.$fetch({
            url: 'tag/list/' + corp + '/'+type,
            method: 'GET',
            dataType:'JSON'
        })
        
    },

    /**
     * 获取企业标签列表
     * 
     * @param {*} corp 
     * @param {*} type 
     */
    getList(corp,type) {

        return Vue.prototype.$fetch({
            url: 'tag/taglist/' + corp + '/'+type,
            method: 'GET',
            dataType:'JSON'
        })
        
    },

    /**
     * 根据TAG_TYPE获取所有的数据 返回列表是树形结构的
     * 
     * @param {*} params 
     */
    getByParam(params) {
        let corp = params.corp
        let type = params.type
    
        return Vue.prototype.$fetch({
            url: 'tag/list/' + corp + '/'+type,
            method: 'GET',
            dataType:'JSON'
        })
        
    },

    /**
     * 通过名称获取企业标签
     * 
     * @param {*} corp 
     * @param {*} tagName 
     */
    getByName(corp,tagName) {

        return Vue.prototype.$fetch({
            url: 'tag/list/' + corp +'/'+ tagName,
            method: 'GET',
            dataType:'JSON'
        })
        
    },

    /**
     * 通过父节点获取所有标签
     * 
     * @param {*} params 
     */
    getChild(params) {
        let corp = params.corp
        let parentCode = params.parentCode
        return Vue.prototype.$fetch({
            url: 'tag/child/' + corp +'/'+ parentCode,
            method: 'GET',
            dataType:'JSON'
        })
    },

    /**
     * 根据TAG_TYPE获取所有的数据
     * 
     * @param {*} params 
     */
    getByType(params) {
        let corp = params.corp
        let type = params.type
        return Vue.prototype.$fetch({
            url: 'tag/all/' + corp +'/'+ type,
            method: 'GET',
            dataType:'JSON'
        })
    }

}