import Vue from 'vue'

export default {
    /**
     * 用户登录
     * 
     * @param {string} username 用户编号哦
     * @param {string} password 密码
     */
    login(username,password) {
        const data = {
            userId: username,
            password: password
        }

        return Vue.prototype.$fetch({
            url: '/login',
            method: 'POST',
            dataType:'JSON',
            data
        })
    },
    /**
     * 获取电脑端用户数据包括用户基本信息、系统权限和可访问的路由
     * 
     * @param {*} userId 用户编号
     */
    getSytemData(userId){
        var params = {userid:userId}

        return Vue.prototype.$fetch({
            url: '/um/pc/user/get',
            method: 'GET',
            dataType: 'JSON',
            params: params
        })
    },

    /**
     * 本地暂存用户信息
     * 
     * @param {*} packData 
     */
    loadSystemData(packData) {
        // 配置用户信息
        sessionStorage.setItem("account",packData.account);
        sessionStorage.setItem("account-code",packData.accountCode);
        sessionStorage.setItem("account-name",packData.accountName);
        sessionStorage.setItem("corp",packData.corp);
        sessionStorage.setItem("corp-code",packData.corpCode);
        sessionStorage.setItem("corp-name",packData.corpName);
        sessionStorage.setItem("org",packData.org);
        sessionStorage.setItem("org-code",packData.orgCode);
        sessionStorage.setItem("org-name",packData.orgName);

        // 配置系统权限
        sessionStorage.setItem("permission",JSON.stringify(packData.permissions));

        // 配置路由
        let routeList = packData.routers;
        if(!routeList){
          routeList = []
        }
        sessionStorage.setItem("ext_route",JSON.stringify(routeList));
    },

    /**
     * 获取电脑端用户可使用的应用
     *
     * @param {*} userId 用户编号
     */
    getAuthorizedApplications(corporationId,userId){
        var params = {
            entId:corporationId,
            userid:userId
        }

        return Vue.prototype.$fetch({
            url: '/um/pc/user/app/list',
            method: 'GET',
            dataType: 'JSON',
            params: params
        })
    },

    /**
     * 修改用户登录密码
     * 
     * @param {*} userId 用户编号
     * @param {*} password 原密码
     * @param {*} newPassword 新密码
     */
    changePassword(userId,password,newPassword){
        const data = {
            userId:userId,
            password: password,
            newPassword:newPassword
        }
    
        return Vue.prototype.$fetch({
            url: '/user/password',
            method: 'POST',
            dataType:'JSON',
            data
        })

    },

    /**
     * 重置用户登录密码
     */
    resetPassword(data){
        return Vue.prototype.$fetch({
            url: '/user/resetPassword',
            method: 'POST',
            dataType:'JSON',
            data
        })

    }
}
