import Vue from 'vue'

export default {

    /**
     * 注册用户
     * @param {User} data 用户信息 
     */
    registeUser(data) {
        return Vue.prototype.$fetch({
            url: '/user/create',
            method: 'POST',
            dataType:'JSON',
            data
        })
    },

    /**
     * 更新用户信息,不更新密码
     * 
     * @param {*} data 用户信息
     */
    update(data) {
        return Vue.prototype.$fetch({
            url: '/user/update',
            method: 'POST',
            dataType:'JSON',
            data
        })
    },

    /**
     * 更新用户密码
     * 
     * @param {用户编号}} userId 
     * @param {原密码} password 
     * @param {新密码} newPassword 
     */
    updatePwd(userId,password,newPassword) {
        const params = {
            userId:userId,
            password: password,
            newPassword:newPassword
        }

        return Vue.prototype.$fetch({
            url: '/user/updatePwd',
            method: 'GET',
            dataType:'JSON',
            params:params
        })
    },

    /**
     * 获取用户信息
     * 
     * @param {String} userId 
     */
    getUserInfo(userId) {
        var params = {userid: userId}
        return Vue.prototype.$fetch({
            url: '/user/get',
            method: 'GET',
            dataType:'JSON',
            params: params
        })
    },

    /**
     * 用户订阅应用
     * 
     * @param {Application} data 
     */
    subscriptUserApp(data) {
        return Vue.prototype.$fetch({
            url: '/userapp/create',
            method: 'POST',
            dataType:'JSON',
            data
        }) 
    },

    /**
     * 用户取消订阅
     * 
     * @param {*} userId 用户编号
     * @param {*} appId 应用编号
     */
    unsubscriptUserApp(userId,appId) {
        
        var params = {
            userid:userId,
            appid:appId
        }

        return Vue.prototype.$fetch({
            url: '/userapp/remove',
            method: 'GET',
            dataType:'JSON',
            params: params
        })
        
    },

    /**
     * 获取用户应用列表
     * 
     * @param {string} userId  用户编号
     */
    getUserApps(userId) {
        return Vue.prototype.$fetch({
            url: '/userapp/list',
            method: 'GET',
            dataType:'JSON',
            params:{userid:userId}
        }) 
    },

    /**
     * 获取路由
     * 
     * @param {string} entId 企业编号
     * @param {string} userId 用户编号
     */
    fetchRouter(entId,userId) {
        const params = {
            entId:entId,
            userid: userId
        }

        return Vue.prototype.$fetch({
            url: '/userapp/routes',
            method: 'GET',
            dataType:'JSON',
            params:params
        })  
    },

    /**
     * 获取用户企业用户列表
     * 
     * @param {*} data 
     */
    getEntUserList(data) {
        return Vue.prototype.$fetch({
            url: '/user/list',
            method: 'POST',
            dataType:'JSON',
            params: {filter:JSON.stringify(data)}
        })
    }
}
